@@ -3,10 +3,12 @@
 // SPDX-License-Identifier: GPL-3.0-only
 
 #include "filesystem.h"
+#include <QDebug>
 
 namespace DiskManager {
 
 FileSystem::FileSystem()
 {
+    // qDebug() << "Constructing a FileSystem object.";
 }
 } // namespace DiskManager
